@@ -71,7 +71,7 @@ gnome_url_default_handler (void)
 			/* It's the first time gnome_url_show is run, so up some useful defaults */
 
 			/* FIXME: Should we remove gnome-help-browser here? */
-			app = gnome_is_program_in_path ("nautilus");
+			app = g_find_program_in_path ("nautilus");
 			if (app) {
 				g_free (app);
 				app = "nautilus \"%s\"";
@@ -134,6 +134,7 @@ gnome_url_show (const gchar *url, GError **error)
 	const char **argv;
 	char **newargv;
 	gboolean ret;
+	gchar *tmp;
 	
 	g_return_val_if_fail (url != NULL, FALSE);
 
@@ -148,7 +149,7 @@ gnome_url_show (const gchar *url, GError **error)
 		protocol = g_new (gchar, pos - url + 1);
 		strncpy (protocol, url, pos - url);
 		protocol[pos - url] = '\0';
-		g_strdown (protocol);
+		g_ascii_strdown (protocol, -1);
 
 		/* init our gconf stuff if necessary */
 		gnome_gconf_lazy_init ();
@@ -183,7 +184,7 @@ gnome_url_show (const gchar *url, GError **error)
 		g_free (template);
 		return FALSE;
 	}
-	
+
 	newargv = g_new0 (char *, argc + 1);
 	for (i = 0; i < argc; i++) {
 		if (strcmp (argv[i], "%s") == 0)
@@ -192,6 +193,14 @@ gnome_url_show (const gchar *url, GError **error)
 			newargv[i] = g_strdup (argv[i]);
 	}
 	newargv[i] = NULL;
+	
+	tmp = g_strjoinv (" ", newargv);
+	g_strfreev (newargv);
+	newargv = g_new0 (char *, 4);
+	newargv[0] = gnome_util_user_shell ();
+	newargv[1] = g_strdup ("-c");
+	newargv[2] = tmp;
+	newargv[3] = NULL;
 
 	/* the way the poptParseArgvString works is that the entire thing
 	 * is allocated as one buffer, so just free will suffice, also
@@ -207,11 +216,11 @@ gnome_url_show (const gchar *url, GError **error)
 			     NULL /* data */,
 			     NULL /* child_pid */,
 			     error);
-	
+
 	g_strfreev (newargv);
 	g_free (template);
 
-	return TRUE;
+	return ret;
 }
 
 /**
